@@ -12,23 +12,24 @@ class ResponseException(Exception):
     """
     response = None
 
+    #: If true, the error response will be returned immediately without trying
+    #: any other routes.
+    is_final = True
 
-class _NotFound(ResponseException):
+
+class NotFound(ResponseException):
+    """\
+    Raised when a view needs to signal a 404 not found condition.
+    """
     response = Response.not_found()
 
-
-class NotFound(_NotFound):
-    """\
-    Raised when a view needs to signal a 404 not found condition. Other routes
-    will be given the opportunity to handle the request, if no others are able
-    to, 404 not found response will be returned. """
-
-
-class NotFoundFinal(_NotFound):
-    """\
-    Return a 404 response directly, even if there may be other views available
-    to handle the request.
-    """
+    def __init__(self, final=False):
+        """
+        ``final`` is false by default, meaning other routes will be offered the
+        opportunity to handle the request. Only after other routes have been
+        tried will an error response be returned.
+        """
+        self.is_final = final
 
 
 class BadRequest(ResponseException):
@@ -87,3 +88,12 @@ class RequestParseError(BadRequest):
     """\
     An error was encountered while parsing the HTTP request.
     """
+
+
+class MethodNotAllowed(ResponseException):
+    """\
+    The URL is valid, but does not respond to the requested method
+    """
+    def __init__(self, valid_methods):
+        super(MethodNotAllowed, self).__init__(valid_methods)
+        self.response = Response.method_not_allowed(valid_methods)
