@@ -23,6 +23,7 @@ class MultiDict(MutableMapping):
 
     Synopsis::
 
+        >>> from fresco.multidict import MultiDict
         >>> d = MultiDict([('a', 1), ('a', 2), ('b', 3)])
         >>> d['a']
         1
@@ -32,7 +33,7 @@ class MultiDict(MutableMapping):
         [1, 2]
         >>> d.getlist('b')
         [3]
-        >>> list(d.iterallitems())
+        >>> list(d.allitems())
         [('a', 1), ('a', 2), ('b', 3)]
 
     """
@@ -46,22 +47,26 @@ class MultiDict(MutableMapping):
 
             1. From a sequence of ``(key, value)`` pairs::
 
+                >>> from fresco.multidict import MultiDict
                 >>> MultiDict([('a', 1), ('a', 2)])
                 MultiDict([('a', 1), ('a', 2)])
 
             2. Initialized from another MultiDict::
 
+                >>> from fresco.multidict import MultiDict
                 >>> d = MultiDict([('a', 1), ('a', 2)])
                 >>> MultiDict(d)
                 MultiDict([('a', 1), ('a', 2)])
 
             3. Initialized from a regular dict::
 
+                >>> from fresco.multidict import MultiDict
                 >>> MultiDict({'a': 1})
                 MultiDict([('a', 1)])
 
             4. From keyword arguments::
 
+                >>> from fresco.multidict import MultiDict
                 >>> MultiDict(a=1)
                 MultiDict([('a', 1)])
 
@@ -174,12 +179,6 @@ class MultiDict(MutableMapping):
             >>> d.items()
             [('a', 1), ('b', 3)]
         """
-        return list(self.iteritems())
-
-    def iteritems(self):
-        """
-        Like ``items``, but return an iterator rather than a list.
-        """
         seen = set()
         for k, v in self._order:
             if k in seen:
@@ -195,13 +194,7 @@ class MultiDict(MutableMapping):
             >>> d.listitems()
             [('a', [1, 2]), ('b', [3])]
         """
-        return list(self.iterlistitems())
-
-    def iterlistitems(self):
-        """
-        Like ``listitems``, but return an iterator rather than a list.
-        """
-        for k in self.iterkeys():
+        for k in self.keys():
             yield k, self._dict[k]
 
     def allitems(self):
@@ -209,16 +202,11 @@ class MultiDict(MutableMapping):
         Return a list of ``(key, value)`` pairs for each item in the MultiDict.
         Items with multiple keys will have multiple key-value pairs returned::
 
+            >>> from fresco.multidict import MultiDict
             >>> d = MultiDict([('a', 1), ('a', 2), ('b', 3)])
             >>> d.allitems()
             [('a', 1), ('a', 2), ('b', 3)]
         """
-        return list(self.iterallitems())
-
-    def iterallitems(self):
-        """
-        Like ``allitems``, but return an iterator rather than a list.
-        """
         return iter(self._order)
 
     def keys(self):
@@ -226,39 +214,24 @@ class MultiDict(MutableMapping):
         Return dictionary keys. Each key is returned only once, even if
         multiple values are present.
 
+            >>> from fresco.multidict import MultiDict
             >>> d = MultiDict([('a', 1), ('a', 2), ('b', 3)])
-            >>> d.keys()
+            >>> list(d.keys())
             ['a', 'b']
         """
-        return list(self.iterkeys())
-
-    def iterkeys(self):
-        """
-        Iterator for dictionary keys. Each key is returned only once, even if
-        multiple values are present.
-
-            >>> d = MultiDict([('a', 1), ('a', 2), ('b', 3)])
-            >>> d.keys()
-            ['a', 'b']
-        """
-        return (k for k, v in self.iteritems())
+        return (k for k, v in self.items())
 
     def values(self):
         """
         Return values from the dictionary. Where keys have multiple values,
         only the first is returned::
 
+            >>> from fresco.multidict import MultiDict
             >>> d = MultiDict([('a', 1), ('a', 2), ('b', 3)])
             >>> d.values()
             [1, 3]
         """
-        return list(self.itervalues())
-
-    def itervalues(self):
-        """
-        Like ``values``, but return an iterator rather than a list.
-        """
-        return (v for k, v in self.iteritems())
+        return (v for k, v in self.items())
 
     def listvalues(self):
         """
@@ -267,18 +240,12 @@ class MultiDict(MutableMapping):
 
         Example usage::
 
+            >>> from fresco.multidict import MultiDict
             >>> d = MultiDict([('a', 1), ('a', 2), ('b', 3)])
             >>> d.listvalues()
             [[1, 2], [3]]
         """
-        return list(self.iterlistvalues())
-
-    def iterlistvalues(self):
-        """
-        Like ``listvalues``, but returns an iterator over the results instead
-        of a list.
-        """
-        return (self._dict[k] for k in self.iterkeys())
+        return (self._dict[k] for k in self.keys())
 
     def pop(self, key, *args):
         """
@@ -410,9 +377,9 @@ class MultiDict(MutableMapping):
         other, replace = args
 
         if isinstance(other, self.__class__):
-            items = other.allitems()
+            items = list(other.allitems())
         elif isinstance(other, dict):
-            items = list(other.iteritems())
+            items = list(other.items())
         else:
             items = list(other)
 
