@@ -9,7 +9,8 @@ HTTP headers and request data (eg query string or submitted form data).
 import posixpath
 import re
 
-from fresco.compat import string_types, quote, urlparse, urlunparse, ParseResult
+from fresco.compat import string_types, quote, urlparse, urlunparse, \
+                          ParseResult
 from fresco.util.wsgi import environ_to_unicode
 
 import fresco
@@ -114,11 +115,8 @@ class Request(object):
         Return a MultiDict of all ``FileUpload`` objects available.
         """
         if self._files is None:
-            self._files = MultiDict(
-                (k, v)
-                for k, v in self.form.iterallitems()
-                if isinstance(v, FileUpload)
-            )
+            self._files = MultiDict((k, v) for k, v in self.form.allitems()
+                                           if isinstance(v, FileUpload))
         return self._files
 
     @property
@@ -409,9 +407,9 @@ class Request(object):
         :param kwargs:      Any remaining keyword arguments are appended to the
                             querystring
 
-        All arguments (other than ``query``, see examples below) should be
-        native strings, translatable to bytes via the latin-1
-        encoding in the case of python3.
+        All arguments (other than ``query``, see examples below) may be
+        byte strings or unicode strings (native strings in python 3). Where
+        necessary values will be converted to utf-8 encoded byte strings.
 
         Examples:
 
@@ -476,25 +474,25 @@ class Request(object):
 
         """
         url = []
-
         parsed_url = self.parsed_url
 
         if path is not None:
-            if isinstance(path, bytes):
-                path = path.decode('iso-8859-1')
             if path[0] != '/':
-                path = posixpath.join(posixpath.dirname(parsed_url[2]), path)
+                path = posixpath.join(
+                        posixpath.dirname(parsed_url[2]), path)
                 path = posixpath.normpath(path)
 
         elif SCRIPT_NAME is not None or PATH_INFO is not None:
             if SCRIPT_NAME is None:
-                SCRIPT_NAME = self.environ.get('SCRIPT_NAME', '')
+                SCRIPT_NAME = self.script_name
             if PATH_INFO is None:
-                PATH_INFO = self.environ('PATH_INFO', '')
+                PATH_INFO = self.path_info
             path = SCRIPT_NAME + PATH_INFO
         else:
             path = parsed_url[2]
 
+        if not isinstance(path, bytes):
+            path = path.encode('utf-8')
         path = quote(path)
 
         if query is not None:
