@@ -41,26 +41,27 @@ class TestMultDict(object):
 
     def test_copy_is_equal(self):
         m = MultiDict([('a', 1), ('a', 2)])
-        assert_equal(m.allitems(), m.copy().allitems())
+        assert_equal(list(m.allitems()),
+                     list(m.copy().allitems()))
 
     def test_copy_is_independent(self):
         m = MultiDict([('a', 1), ('a', 2)])
         n = m.copy()
         n['b'] = 'foo'
-        assert_equal(m.allitems(), [('a', 1), ('a', 2)])
-        assert_equal(n.allitems(), [('a', 1), ('a', 2), ('b', 'foo')])
+        assert_equal(list(m.allitems()), [('a', 1), ('a', 2)])
+        assert_equal(list(n.allitems()), [('a', 1), ('a', 2), ('b', 'foo')])
 
     def test_fromkeys(self):
         m = MultiDict.fromkeys(['a', 'b'])
-        assert_equal(m.allitems(), [('a', None), ('b', None)])
+        assert_equal(list(m.allitems()), [('a', None), ('b', None)])
 
     def test_fromkeys_with_value(self):
         m = MultiDict.fromkeys(['a', 'b'], 42)
-        assert_equal(m.allitems(), [('a', 42), ('b', 42)])
+        assert_equal(list(m.allitems()), [('a', 42), ('b', 42)])
 
     def test_items_only_returns_first_of_each(self):
         m = MultiDict([('a', 1), ('a', 2)])
-        assert_equal(m.items(), [('a', 1)])
+        assert_equal(list(m.items()), [('a', 1)])
 
     def test_listitems_returns_lists(self):
         m = MultiDict([('a', 1), ('a', 2)])
@@ -70,45 +71,30 @@ class TestMultDict(object):
         m = MultiDict([('a', 1), ('a', 2)])
         assert_equal(list(m.allitems()), [('a', 1), ('a', 2)])
 
-    def test_iterallitems_returns_iterator(self):
+    def test_allitems_returns_iterator(self):
         m = MultiDict([('a', 1), ('a', 2)])
-        i = m.iterallitems()
-        assert_equal(i.next(), ('a', 1))
-        assert_equal(i.next(), ('a', 2))
-        assert_raises(StopIteration, i.next)
+        i = m.allitems()
+        assert_equal(next(i), ('a', 1))
+        assert_equal(next(i), ('a', 2))
+        assert_raises(StopIteration, lambda: next(i))
 
     def test_keys(self):
         m = MultiDict([('a', 1), ('a', 2), ('b', 3)])
-        assert_equal(m.keys(), ['a', 'b'])
-
-    def test_iterkeys(self):
-        m = MultiDict([('a', 1), ('a', 2), ('b', 3)])
-        i = m.iterkeys()
-        assert_equal(i.next(), 'a')
-        assert_equal(i.next(), 'b')
-        assert_raises(StopIteration, i.next)
+        i = m.keys()
+        assert_equal(next(i), 'a')
+        assert_equal(next(i), 'b')
+        assert_raises(StopIteration, lambda: next(i))
 
     def test_values(self):
         m = MultiDict([('a', 1), ('a', 2), ('b', 3)])
-        assert_equal(m.values(), [1, 3])
-
-    def test_itervalues(self):
-        m = MultiDict([('a', 1), ('a', 2), ('b', 3)])
-        i = m.itervalues()
-        assert_equal(i.next(), 1)
-        assert_equal(i.next(), 3)
-        assert_raises(StopIteration, i.next)
+        i = m.values()
+        assert_equal(next(i), 1)
+        assert_equal(next(i), 3)
+        assert_raises(StopIteration, lambda: next(i))
 
     def test_listvalues(self):
         m = MultiDict([('a', 1), ('a', 2), ('b', 3)])
-        assert_equal(m.listvalues(), [[1, 2], [3]])
-
-    def test_iterlistvalues(self):
-        m = MultiDict([('a', 1), ('a', 2), ('b', 3)])
-        i = m.iterlistvalues()
-        assert_equal(i.next(), [1, 2])
-        assert_equal(i.next(), [3])
-        assert_raises(StopIteration, i.next)
+        assert_equal(list(m.listvalues()), [[1, 2], [3]])
 
     def test_setitem(self):
         m = MultiDict()
@@ -221,13 +207,13 @@ class TestMultDict(object):
     def test_pop(self):
         m = MultiDict([('a', 1), ('b', 2), ('a', 3)])
         assert_equal(m.pop('b'), 2)
-        assert_equal(m.allitems(), [('a', 1), ('a', 3)])
+        assert_equal(list(m.allitems()), [('a', 1), ('a', 3)])
         m.check_consistency()
 
     def test_pop_returns_first_item(self):
         m = MultiDict([('a', 1), ('b', 2), ('a', 3)])
         assert_equal(m.pop('a'), 1)
-        assert_equal(m.allitems(), [('b', 2), ('a', 3)])
+        assert_equal(list(m.allitems()), [('b', 2), ('a', 3)])
         m.check_consistency()
 
     def test_pop_with_default(self):
@@ -244,7 +230,7 @@ class TestMultDict(object):
 
         try:
             m.popitem()
-        except KeyError, e:
+        except KeyError:
             pass
         else:
             assert False, "Expected KeyError in popitem from empty MultiDict"
